Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(21)

Unified Diff: include/gpu/GrProgramElement.h

Issue 574333003: Rename GrProgramResource to GrGpuResourceRef (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: add newline before private: Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « include/gpu/GrGpuResourceRef.h ('k') | include/gpu/GrProgramResource.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/gpu/GrProgramElement.h
diff --git a/include/gpu/GrProgramElement.h b/include/gpu/GrProgramElement.h
index 5f88a2a68f79896cf1880692c8f0659c8d702bd6..8d23ba203576af057c6b22b21547ef048c3008c3 100644
--- a/include/gpu/GrProgramElement.h
+++ b/include/gpu/GrProgramElement.h
@@ -11,7 +11,7 @@
#include "SkRefCnt.h"
#include "SkTArray.h"
-class GrProgramResource;
+class GrGpuResourceRef;
/**
* Base class for GrEffect (and future GrGeometryProcessor). GrDrawState uses this to manage
@@ -19,8 +19,8 @@ class GrProgramResource;
* converts resources owned by the effect from being ref'ed to having pending reads/writes.
*
* All GrGpuResource objects owned by a GrProgramElement or derived classes (either directly or
* indirectly) must be wrapped in a GrProgramResource and registered with the GrProgramElement using
* addGrProgramResource(). This allows the regular refs to be converted to pending IO events
* when the program element is scheduled for deferred execution.
*/
class GrProgramElement : public SkNoncopyable {
@@ -67,10 +67,10 @@ protected:
/** Subclasses registers their resources using this function. It is assumed the GrProgramResouce
is and will remain owned by the subclass and this function will retain a raw ptr. Once a
- GrProgramResource is registered its setResource must not be called.
+ GrGpuResourceRef is registered its setResource must not be called.
*/
- void addProgramResource(const GrProgramResource* res) {
- fProgramResources.push_back(res);
+ void addGpuResource(const GrGpuResourceRef* res) {
+ fGpuResources.push_back(res);
}
private:
@@ -85,7 +85,7 @@ private:
mutable int32_t fPendingExecutions;
uint32_t fUniqueID;
- SkSTArray<4, const GrProgramResource*, true> fProgramResources;
+ SkSTArray<4, const GrGpuResourceRef*, true> fGpuResources;
// Only this class can access convertRefToPendingExecution() and completedExecution().
template <typename T> friend class GrProgramElementRef;
« no previous file with comments | « include/gpu/GrGpuResourceRef.h ('k') | include/gpu/GrProgramResource.h » ('j') | no next file with comments »
@@ -19,8 +19,8 @@ class GrProgramResource;
*
* All GrGpuResource objects owned by a GrProgramElement or derived classes (either directly or
- * indirectly) must be wrapped in a GrProgramResource and registered with the GrProgramElement using
- * addGrProgramResource(). This allows the regular refs to be converted to pending IO events
+ * indirectly) must be wrapped in a GrGpuResourceRef and registered with the GrProgramElement using
+ * addGpuResource(). This allows the regular refs to be converted to pending IO events
* when the program element is scheduled for deferred execution.
*/

Powered by Google App Engine
This is Rietveld 408576698